<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Funnel Page</title>

    <!-- Add Tailwind CSS via Vite -->
    @vite(['resources/css/app.css'])

    <!-- Add Alpine.js for handling the modal -->
    <script src="https://cdn.jsdelivr.net/npm/alpinejs@2.8.2/dist/alpine.min.js" defer></script>
</head>

<body class="bg-gray-50 flex items-center justify-center ">

    <div class="container max-w-6xl p-8 ">

        <?php $funnelContent = json_decode($funnelPage->funnel_content); ?>

        <!-- Headline -->
        <h1 class="text-center mb-4 text-4xl font-extrabold text-gray-700 leading-[45px] sm:leading-6 md:leading-snug">{!! $funnelContent->headline !!}</h1>

        <!-- Subheadline -->
        <p class="sm:max-w-[800px] m-auto text-xl text-gray-600 text-center mb-8">{!! $funnelContent->subheadline !!}</p>

        <!-- Chat Group Link -->
        <div class="text-center mt-8">
            <a href="{{ $funnelContent->chat_group_link }}" target="_blank" class="inline-flex items-center px-6 py-3 bg-blue-500 text-white font-semibold rounded-lg shadow-md hover:bg-blue-600">
                <!-- Icon -->
                <svg class="h-6 w-6 text-white mr-2" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                    <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M17 8l4 4m0 0l-4 4m4-4H3"/>
                </svg>
                Join Our Fb Group
            </a>
        </div>

        <div class="container w-full flex flex-col sm:flex-row sm:max-w-6xl mt-10">
            <!-- Property Image (Left) -->
            <div class="w-full sm:w-[70%] sm:pr-8 mb-6">
                <img class="w-full rounded-lg shadow-lg transition-all duration-300 hover:scale-105"
                     src="{{ $funnelContent->property_image }}" alt="Property Image">
            </div>

            <!-- Floor Plan Images (Right) -->
            <div class="w-full sm:w-1/2">
                <div class="gap-4 sm:grid grid-cols-2 sm:gap-6">
                    @foreach ($funnelContent->floor_images as $floorImage)
                        <div class="relative">
                            <img class="w-full h-auto rounded-lg shadow-md transition-all duration-300 hover:scale-105 mb-4 floor-image cursor-pointer"
                                 src="{{ $floorImage }}" alt="Floor Plan Image">
                        </div>
                    @endforeach
                </div>
            </div>
        </div>

        <!-- Video Embed -->
        <div class="relative overflow-hidden rounded-lg shadow-lg mb-6 mt-6" style="padding-top: 56.25%; background-color: #000; border: 10px solid #fff;">
            <iframe class="absolute inset-0 w-full h-full rounded-lg"
                    src="{{ $funnelContent->video_link }}"
                    frameborder="0"
                    allowfullscreen
                    style="border: none;">
            </iframe>
        </div>

    </div>

    <!-- Modal -->
    <div x-data="{ open: false, imageSrc: '' }" x-show="open" @keydown.escape="open = false" class="fixed inset-0 flex items-center justify-center bg-black bg-opacity-50 z-50 p-6" @click.self="open = false">
        <div class="bg-white rounded-lg overflow-hidden w-full max-w-4xl">
             <!-- Close Icon -->
                <button @click="open = false" class="absolute top-4 buttom-6 right-4 text-white ">
                    
                    <svg class="h-8 w-8" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round">
                        <rect x="3" y="3" width="18" height="18" rx="2" ry="2" />
                        <line x1="9" y1="9" x2="15" y2="15" />
                        <line x1="15" y1="9" x2="9" y2="15" />
                    </svg>
                </button>
            <div class="relative">
               
                <img :src="imageSrc" alt="Modal Image" class="w-full h-auto rounded-lg shadow-md">
            </div>
        </div>
    </div>

    <!-- Image Click to Open Modal -->
    <script>
        document.querySelectorAll('.floor-image').forEach(image => {
            image.addEventListener('click', function() {
                const modal = document.querySelector('[x-data]');
                modal.__x.$data.open = true;
                modal.__x.$data.imageSrc = this.src;
            });
        });
    </script>

</body>

</html>
